# Avocado

[![Build Status](https://travis-ci.org/chop-dbhi/avocado.svg?branch=master)](https://travis-ci.org/chop-dbhi/avocado) [![Coverage Status](https://img.shields.io/coveralls/chop-dbhi/avocado.svg)](https://coveralls.io/r/chop-dbhi/avocado)

Metadata APIs for Django.

## Documentation

http://avocado.harvest.io

## Development

See the [contributing](https://github.com/chop-dbhi/cilantro/blob/master/CONTRIBUTING.md) guide.

## Data Model

![Avocado ER Diagram](./avocado_erd.png)
